library(rhdf5)
library(dplyr)
library(ggplot2)


fn <- "demo-data.hdf5"
df <- h5read(fn, "data/predictive_cis") %>% select(fs_date, date, prob, ymin, ymax)
obs <- h5read(fn, "data/obs")

plot_fs_date <- df$fs_date %>% unique() %>% `[`(3)
plot_df <- filter(df, fs_date == plot_fs_date, prob %in% c(0, 50))
plot_obs <- mutate(obs, observed = as.Date(date) > plot_fs_date)

g <- ggplot() +
  geom_ribbon(mapping = aes(x = as.Date(date), ymin = ymin, ymax = ymax), fill = "blue", alpha = 0.1, data = filter(plot_df, prob == 50)) +
  geom_line(mapping = aes(x = as.Date(date), y = ymin), colour = "blue", data = filter(plot_df, prob == 0)) +
  geom_point(mapping = aes(x = as.Date(date), y = value, shape = observed), data = plot_obs) +
  labs(x = "Date", y = "Notifications") +
  theme(legend.position="none") +
  theme_classic()

ggsave("demo-data.pdf", plot = g, width = 10, height = 5)
